<?php
/**
 * @package Joomla
 * @subpackage EasyCookieInfo
 * @copyright 2017 Thomas Römer
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @author Thomas Römer <open@roemer-online.net>
 *
 * This module is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 (GPLv2) of the License, or (at your option) any later version.
 *
 * This module is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 *  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details <http://www.gnu.org/licenses/>.
 *
 **/

defined( '_JEXEC' ) or die( 'Restricted access' );

// Create a unique cookie name for this Joomla installation (because you may have multiple Joomla sites under the same domain)
$cookie_name = 'cookie_' . md5(JPATH_SITE);

$app = JFactory::getApplication();
// Get GET
$inputGet = $app->input->get($cookie_name);
// Get COOKIE
$inputCookie  = $app->input->cookie->get($name = $cookie_name, $defaultValue = null);

if($inputGet == 'accepted') {
	// Set accept cookie (if user has javascript disabled)
	setcookie($cookie_name, 'accepted', time()+3600*24*365, '/');
}
elseif($inputCookie == null) {
	// If accept cookie has not yet been set...
	
	// Get position setting
	$position = $params->get('position', 'top');
	if(!in_array($position, array('top', 'bottom'))) $position = 'top';

	// Get current language
	$current_lang = array();
	$lang = JFactory::getLanguage();
	$current_lang[] = $lang->getTag();
	$current_lang[] = explode('-', $lang->getTag())[0];

	// Get Strings
	$info_text = getLangString($params->get('info_text', 'en=This website uses cookies to ensure you get the best experience.'), $current_lang);
	$link_url = getLangString($params->get('link_url'), $current_lang, true);
	$button_caption = getLangString($params->get('button_caption', 'en=Accepted'), $current_lang);
	$link = '';
	if($link_url) {
		$link_text = getLangString($params->get('link_text', 'en=Learn more about it.'), $current_lang);
		$link = ' <a href="' . $link_url . '">' . $link_text . '</a>';
	}
	
	// Get current URL
	$objJURI = JFactory::getURI();
	$strQuery = '';
	
	if(!empty($objJURI->getQuery())) {
		$strQuery = '?' . $objJURI->getQuery() . '&amp;' . $cookie_name . '=accepted';
	}
	else {
		$strQuery = '?' . $cookie_name . '=accepted';
	}
	
	$currentURL = $objJURI->current() . $strQuery;

	// Module template
	require JModuleHelper::getLayoutPath('mod_easycookieinfo', $params->get('layout', 'default'));
}

function getLangString($str, $lang, $isURL = false) {
	if($str == '') return '';
	if(empty($lang) OR count($lang) != 2) $lang = array('en-GB', 'en');

	$strings = array();
	$lang_strings = array();
	$strings = explode(PHP_EOL, $str);
	$strings = array_filter($strings, function($value) { return $value !== ''; });
	
	foreach($strings as $s) {
		$tmp = explode('=', $s);
		if(isset($tmp[1])) {
			if($isURL AND intval($tmp[1]) > 0) {
				$lang_strings[trim($tmp[0])] = 'index.php?Itemid=' . intval($tmp[1]);
			}
			else {
				$lang_strings[trim($tmp[0])] = trim($tmp[1]);
			}
		}
		elseif(isset($tmp[0])) {
			if($isURL AND intval($tmp[0]) > 0) {
				$lang_strings['default'] = 'index.php?Itemid=' . intval($tmp[0]);
			}
			else {
				$lang_strings['default'] = trim($tmp[0]);
			}
		}
	}

	if(isset($lang_strings[$lang[0]])) return $lang_strings[$lang[0]];
	if(isset($lang_strings[$lang[1]])) return $lang_strings[$lang[1]];
	if(isset($lang_strings['default'])) return $lang_strings['default'];
	if(isset($lang_strings['en-GB'])) return $lang_strings['en-GB'];
	if(isset($lang_strings['en'])) return $lang_strings['en'];
}
?>